==> react-7.5.0.tgz: package/es/AlertCallContainer/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import PropTypes from 'prop-types';
import { AlertCall } from "./..";
import { bind, reject, uniqueId } from 'lodash';

var AlertCallContainer =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(AlertCallContainer, _React$Component);

  function AlertCallContainer() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      alertList: []
    }, _this.callAlert = function (title, caller, deviceListHeader, devices, onReject, onAnswerVoice, onAnswerVideo, onDeviceSelect) {
      _this.handleCallAlert(title, caller, deviceListHeader, devices, onReject, onAnswerVoice, onAnswerVideo, onDeviceSelect);
    }, _this.handleCallAlert = function (title, caller, deviceListHeader, devices, onReject, onAnswerVoice, onAnswerVideo, onDeviceSelect) {
      var key = uniqueId('call_alert_');
      var nextAlert = {
        key: key,
        caller: caller,
        deviceListHeader: deviceListHeader,
        devices: devices,
        show: true,
        title: title,
        onReject: bind(_this.handleOnReject, _assertThisInitialized(_assertThisInitialized(_this)), key, onReject),
        onAnswerVoice: onAnswerVoice && bind(_this.handleOnAnswerVoice, _assertThisInitialized(_assertThisInitialized(_this)), key, onAnswerVoice),
        onAnswerVideo: bind(_this.handleOnAnswerVideo, _assertThisInitialized(_assertThisInitialized(_this)), key, onAnswerVideo),
        onDeviceSelect: onDeviceSelect
      };

      if (_this.state.alertList.length < 2) {
        _this.setState(function (state) {
          return {
            alertList: state.alertList.concat([nextAlert])
          };
        });
      }
    }, _this.handleOnReject = function (key, onReject, e) {
      _this.setState(function (state) {
        onReject && onReject(e);
        return {
          alertList: reject(state.alertList, {
            key: key
          })
        };
      });
    }, _this.handleOnAnswerVoice = function (key, onAnswerVoice, e) {
      _this.setState(function (state) {
        onAnswerVoice && onAnswerVoice(e);
        return {
          alertList: reject(state.alertList, {
            key: key
          })
        };
      });
    }, _this.handleOnAnswerVideo = function (key, onAnswerVideo, e) {
      _this.setState(function (state) {
        onAnswerVideo && onAnswerVideo(e);
        return {
          alertList: reject(state.alertList, {
            key: key
          })
        };
      });
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = AlertCallContainer.prototype;

  _proto.render = function render() {
    return React.createElement("div", {
      className: "cui-alert__container cui-alert__container--call"
    }, this.state.alertList.map(function (alert) {
      return React.createElement(AlertCall, {
        key: alert.key,
        title: alert.title,
        caller: alert.caller,
        deviceListHeader: alert.deviceListHeader,
        devices: alert.devices,
        show: alert.show,
        onReject: alert.onReject,
        onAnswerVoice: alert.onAnswerVoice,
        onAnswerVideo: alert.onAnswerVideo,
        onDeviceSelect: alert.onDeviceSelect
      });
    }));
  };

  return AlertCallContainer;
}(React.Component);

AlertCallContainer.displayName = 'AlertCallContainer';
export default AlertCallContainer;

==> react-7.6.0.tgz: package/es/AlertCallContainer/index.js <==
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import PropTypes from 'prop-types';
import { AlertCall } from "./..";
import { bind, reject, uniqueId } from 'lodash';

var AlertCallContainer =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(AlertCallContainer, _React$Component);

  function AlertCallContainer() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this, _this.state = {
      alertList: []
    }, _this.callAlert = function (title, caller, deviceListHeader, devices, onReject, onAnswerVoice, onAnswerVideo, onDeviceSelect, avatar) {
      _this.handleCallAlert(title, caller, deviceListHeader, devices, onReject, onAnswerVoice, onAnswerVideo, onDeviceSelect, avatar);
    }, _this.handleCallAlert = function (title, caller, deviceListHeader, devices, onReject, onAnswerVoice, onAnswerVideo, onDeviceSelect, avatar) {
      var key = uniqueId('call_alert_');
      var nextAlert = {
        avatar: avatar,
        key: key,
        caller: caller,
        deviceListHeader: deviceListHeader,
        devices: devices,
        show: true,
        title: title,
        onReject: bind(_this.handleOnReject, _assertThisInitialized(_assertThisInitialized(_this)), key, onReject),
        onAnswerVoice: onAnswerVoice && bind(_this.handleOnAnswerVoice, _assertThisInitialized(_assertThisInitialized(_this)), key, onAnswerVoice),
        onAnswerVideo: bind(_this.handleOnAnswerVideo, _assertThisInitialized(_assertThisInitialized(_this)), key, onAnswerVideo),
        onDeviceSelect: onDeviceSelect
      };

      if (_this.state.alertList.length < 2) {
        _this.setState(function (state) {
          return {
            alertList: state.alertList.concat([nextAlert])
          };
        });
      }
    }, _this.handleOnReject = function (key, onReject, e) {
      _this.setState(function (state) {
        onReject && onReject(e);
        return {
          alertList: reject(state.alertList, {
            key: key
          })
        };
      });
    }, _this.handleOnAnswerVoice = function (key, onAnswerVoice, e) {
      _this.setState(function (state) {
        onAnswerVoice && onAnswerVoice(e);
        return {
          alertList: reject(state.alertList, {
            key: key
          })
        };
      });
    }, _this.handleOnAnswerVideo = function (key, onAnswerVideo, e) {
      _this.setState(function (state) {
        onAnswerVideo && onAnswerVideo(e);
        return {
          alertList: reject(state.alertList, {
            key: key
          })
        };
      });
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = AlertCallContainer.prototype;

  _proto.render = function render() {
    return React.createElement("div", {
      className: "cui-alert__container cui-alert__container--call"
    }, this.state.alertList.map(function (alert) {
      return React.createElement(AlertCall, {
        avatar: alert.avatar,
        key: alert.key,
        title: alert.title,
        caller: alert.caller,
        deviceListHeader: alert.deviceListHeader,
        devices: alert.devices,
        show: alert.show,
        onReject: alert.onReject,
        onAnswerVoice: alert.onAnswerVoice,
        onAnswerVideo: alert.onAnswerVideo,
        onDeviceSelect: alert.onDeviceSelect
      });
    }));
  };

  return AlertCallContainer;
}(React.Component);

AlertCallContainer.displayName = 'AlertCallContainer';
export default AlertCallContainer;
